@@ -51,6 +51,8 @@ private:
     int lastFreq;
     int currentSet;
     bool isFullScreen;
+    bool resumeAfterCall;
+    bool inizializeAtStartUp;
     QStringList quickAccessButtonsTextList;
     QStringList stationsList;
 
@@ -103,6 +105,7 @@ private slots:
     void on_actionAuto_Scan_triggered();
 
     void callIncoming();
+    void callEnded();
 };
 
 #endif // MAINWINDOW_H
