@@ -40,6 +40,11 @@ SettingsDialog::SettingsDialog(QWidget *parent) :
     ui->buttonsSpinBox->setValue(buttonsSize);
     int stationsSize = settings.value("stationListFontSize", 20).toInt();
     ui->listSpinBox->setValue(stationsSize);
+
+    bool inizializeAtStartUp = settings.value("inizializeAtStartUp", false).toBool();
+    ui->inizializeAtStartUpcheckBox->setChecked(inizializeAtStartUp);
+    bool resumeAfterCall = settings.value("resumeAfterCall", false).toBool();
+    ui->resumeAfterCallCheckBox->setChecked(resumeAfterCall);
 }
 
 SettingsDialog::~SettingsDialog()
@@ -98,6 +103,9 @@ void SettingsDialog::on_saveButton_clicked()
     settings.setValue("buttonsFontSize", ui->buttonsSpinBox->value());
     settings.setValue("stationListFontSize", ui->listSpinBox->value());
 
+    settings.setValue("inizializeAtStartUp", ui->inizializeAtStartUpcheckBox->isChecked());
+    settings.setValue("resumeAfterCall", ui->resumeAfterCallCheckBox->isChecked());
+
     emit saveButtonClicked();
 
     close();
